ploneintranet.api.microblog package
===================================

Submodules
----------

ploneintranet.api.microblog.statusupdate module
-----------------------------------------------

.. automodule:: ploneintranet.api.microblog.statusupdate
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ploneintranet.api.microblog
    :members:
    :undoc-members:
    :show-inheritance:
